/*
 * Copyright (C) 2005-2013 Schlichtherle IT Services.
 * All rights reserved. Use is subject to license terms.
 */
package net.java.truelicense.core;

import de.schlichtherle.license.LicenseContent;
import javax.annotation.concurrent.Immutable;
import net.java.truelicense.core.crypto.*;
import net.java.truelicense.core.io.Transformation;

/**
 * The root context for the management of V1 format license keys.
 *
 * @author Christian Schlichtherle
 */
@Immutable
public abstract class BasicV1LicenseManagementContext
extends BasicLicenseManagementContext {

    protected BasicV1LicenseManagementContext(String subject) { super(subject); }

    // This introduces a cyclic dependency between the packages
    // de.schlichtherle.license and this package.
    // However, this is tolerable.
    /** Returns a <em>new</em> license content. */
    @Override
    public LicenseContent license() { return new LicenseContent(); }

    /**
     * {@inheritDoc}
     * <p>
     * The implementation in the class {@link BasicV1LicenseManagementContext}
     * returns a compression for V1 format license keys.
     */
    @Override
    public final Transformation compression() {
        return new V1Compression();
    }

    /**
     * {@inheritDoc}
     * <p>
     * The implementation in the class {@link BasicV1LicenseManagementContext}
     * returns an encryption for V1 format license keys with the given
     * parameters.
     */
    @Override protected final Encryption encryption(PbeParameters pbe) {
        return new V1Encryption(pbe);
    }
}
